indexing

	description: "Test Posix file descriptor class."

  author: "Berend de Boer"
	date: "$Date: Fri, 13 Oct 2000 13:53:08 +0200 $"
	revision: "$Revision: 1.6 $"

class TEST_P_FILE_DESCRIPTOR

inherit
   
   POSIX_CONSTANTS

   POSIX_SYSTEM

   POSIX_FILE_SYSTEM
      rename
         make as make_file_system
      end
   

creation
   
   make
   
feature
   
   make is
      local
         fd, fd2: POSIX_FILE_DESCRIPTOR
         file: POSIX_TEXT_FILE
         buf: STDC_DYNAMIC_MEMORY
         byte: INTEGER
      do
         print ("testing Posix file descriptor interface.%N")

         make_file_system
         
         print ("Create a file.%N")
         create fd.create_read_write ("test.berend")

         print ("Write a byte to that file.%N")
         create buf.allocate (2)
         buf.poke_byte (0, 65)
         buf.poke_byte (1, 66)
         fd.write (buf.ptr, buf.size)
         fd.close
         
         print ("Open existing file with read-only access.%N")
         create fd.open_read ("test.berend")

         print ("Read a byte.%N")         
         fd.read (buf.ptr, buf.size)
         byte := buf.peek_byte (0)
         if byte = 65 then
            print ("Result is as expected.%N")
         else
            print ("!! Read: ")
            print (byte.out)
            print (" instead of 65.%N")
         end

         print ("File information.%N")         
         print ("size: ")         
         print (fd.status.size.out)
         print (".%N")
         print ("uid: ")         
         print (fd.status.unix_uid.out)
         print (".%N")
         print ("gid: ")         
         print (fd.status.unix_gid.out)
         print (".%N")
         print ("inode: ")         
         print (fd.status.inode.out)
         print (".%N")
         print ("mtime: ")         
         print (fd.status.mtime.out)
         print (".%N")
         if fd.status.size /= 2 then
            print ("!! File size is not equal to 2.%N")
         end

         print ("Test isatty.%N")
         if fd.is_attached_to_terminal then
            print ("Is attached to terminal.%N")
         else
            print ("Is not attached to terminal.%N")
         end
         fd.close

         print ("Open existing file with read and write access.%N")
         create fd.open_read_write ("test.berend")
         print ("Test lseek first byte.%N")
         fd.seek (0)
         fd.read (buf.ptr, 1)
         byte := buf.peek_byte (0)
         if byte = 65 then
            print ("Result is as expected.%N")
         else
            print ("!! Read: ")
            print (byte.out)
            print (" instead of 65.%N")
         end
         print ("Test lseek from end.%N")
         fd.seek_from_end (-1)
         fd.read (buf.ptr, 1)
         byte := buf.peek_byte (0)
         if byte = 66 then
            print ("Result is as expected.%N")
         else
            print ("!! Read: ")
            print (byte.out)
            print (" instead of 66.%N")
         end

         if supports_file_synchronization then
            print ("Synchronize file.%N")
            fd.synchronize
         end
         if supports_synchronized_io then
            print ("Synchronize data.%N")
            fd.synchronize_data
         end
         print ("Close it.%N")
         fd.close

         print ("Test create from file.%N")
         create file.open_read ("test.berend")
         create fd.make_from_file (file)
         print ("file descriptor: ")
         print (fd.value.out)
         print ("%N")

         print ("Test dup.%N")
         create fd2.make_as_duplicate (fd)

         print ("Test dup2.%N")
         fd2.make_as_duplicate (fd)

         fd2.close
         fd.close
         remove_file ("test.berend")

         print ("End of Posix file descriptor test.%N")
      end
   
end -- class TEST_P_FILE_DESCRIPTOR
